@@ -1,4 +1,3 @@
-import logging
 import os
 import signal
 import threading
@@ -6,7 +5,7 @@ import time
 from multiprocessing import Event, Process, Queue
 
 from hyrex.dispatcher import get_dispatcher
-from hyrex.worker.logging import LogLevel, init_logging
+from hyrex.logging import get_logger, LogFeature
 from hyrex.worker.messages.admin_messages import (ExecutorHeartbeatMessage,
                                                   ExecutorStoppedMessage,
                                                   NewExecutorMessage,
@@ -21,10 +20,9 @@ class WorkerAdmin(Process):
         self,
         root_message_queue: Queue,
         admin_message_queue: Queue,
-        log_level: LogLevel,
+        log_level: str,
     ):
         super().__init__()
-        self.logger = logging.getLogger(__name__)
         self.log_level = log_level
 
         self.current_executors = []
@@ -52,8 +50,18 @@ class WorkerAdmin(Process):
                 self.current_executors.append(message.executor_id)
             elif isinstance(message, ExecutorStoppedMessage):
                 # Mark executor as stopped (if not already)
+                self.logger.warning(
+                    f"Executor {message.executor_id} stopped unexpectedly",
+                    feature=LogFeature.DURABILITY,
+                    executor_id=str(message.executor_id)
+                )
                 self.dispatcher.disconnect_executor(message.executor_id)
                 self.dispatcher.mark_running_tasks_lost(message.executor_id)
+                self.logger.info(
+                    f"Marked running tasks as lost for executor {message.executor_id}",
+                    feature=LogFeature.DURABILITY,
+                    executor_id=str(message.executor_id)
+                )
             elif isinstance(message, TaskCanceledMessage):
                 self.dispatcher.task_canceled(message.task_id)
             elif isinstance(message, ExecutorHeartbeatMessage):
@@ -64,8 +72,12 @@ class WorkerAdmin(Process):
                 self.dispatcher.task_heartbeat(message.task_ids, message.timestamp)
 
     def run(self):
-        init_logging(self.log_level)
-
+        # Set log level in environment for any child components
+        os.environ["HYREX_LOG_LEVEL"] = self.log_level
+        
+        # Initialize logger in child process (multiprocessing requirement)
+        self.logger = get_logger("admin", LogFeature.PROCESS_MANAGEMENT, level=self.log_level)
+        
         self.logger.info("Initializing admin.")
         self.dispatcher = get_dispatcher()
 
@@ -107,6 +119,6 @@ class WorkerAdmin(Process):
                 self.logger.info("Message listener thread closed successfully.")
 
         except Exception as e:
-            print(f"Error during main process shutdown: {e}")
+            self.logger.error(f"Error during main process shutdown: {e}")
         self.logger.info("Stopping admin")
         self.dispatcher.stop()
